@@ -40,7 +40,7 @@
 #   getRelativePath("foo/bar", "foo")                   # "bar"
 #   getRelativePath("foo/bar", "foo/bar/yah")           # ".."
 #   getRelativePath("foo/bar/cool", "foo/bar/yah/sub/") # "../../cool"
-#   getRelativePath.default("/foo/bar/", "/bar/foo/")   # "../../foo/bar"
+#   getRelativePath("/tmp/bar/", "/bar/foo/")           # "../../tmp/bar"
 #
 #   # Windows
 #   getRelativePath("C:/foo/bar/", "C:/bar/")           # "../foo/bar"
@@ -140,7 +140,7 @@ setMethodS3("getRelativePath", "default", function(pathname, relativeTo=getwd(),
 
   # 2. Remove all matching components in 'relativeTo' and 'pathname'.
   #    The removed parts constitute their common path.
-  for (kk in seq(length=length(relativeTo))) {
+  for (kk in seq_along(relativeTo)) {
     aPart <- relativeTo[1];
     bPart <- pathnameC[1];
     if (!identical(aPart, bPart))
